# Copyright 2017 John Reese
# Licensed under the MIT license

'''asyncio bridge to sqlite3'''

from sqlite3 import sqlite_version, sqlite_version_info

__version__ = '0.1.0'
__all__ = [
    '__version__',
    'sqlite_version',
    'sqlite_version_info',
]



# Copyright 2017 John Reese
# Licensed under the MIT license

from typing import Any, Generator, Iterable, Union


class ProxyCursor:
    pass


class ProxyConnection:
    def __init__(
        self,
    ) -> None:
        pass

    async def cursor(self) -> ProxyCursor:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def commit(self) -> None:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def rollback(self) -> None:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def close(self) -> None:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def execute(
        self,
        sql: str,
        parameters: Iterable[Any] = None,
    ) -> ProxyCursor:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def executemany(
        self,
        sql: str,
        parameters: Union[Iterable[Iterable[Any]], Generator[Any]] = None,
    ) -> ProxyCursor:
        raise NotImplementedError('Not yet available in aiosqlite')

    async def executescript(
        self,
        sql_script: str,
    ) -> ProxyCursor:
        raise NotImplementedError('Not yet available in aiosqlite')


async def connect(
    database: str,
    *,
    timeout: float = 5.0,
    cached_statements: int = 100,
    uri: bool = False,
) -> ProxyConnection:
    pass



from setuptools import setup

from os import path
import shutil

if path.isfile('README.rst'):
    shutil.copyfile('README.rst', 'README')

setup(
    name='aiosqlite',
    description='asyncio bridge to the standard sqlite3 module',
    version='0.1.0',
    author='John Reese',
    author_email='john@noswap.com',
    url='https://github.com/jreese/aiosqlite',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Development Status :: 3 - Alpha',
    ],
    license='MIT License',
    packages=['aiosqlite'],
    install_requires=[
    ],
)
